import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { memo, useState, useEffect, useRef } from "react";
import { Box } from "@primer/react";
import { PageConfig } from '@jupyterlab/coreutils';
import { useJupyter } from "../../jupyter/JupyterContext";
import JupyterLabAppAdapter from "./JupyterLabAppAdapter";
import JupyterLabAppCss from "./JupyterLabAppCss";
let _adapter = undefined;
// The webpack public path needs to be set before loading the CSS assets.
global.__webpack_public_path__ = PageConfig.getOption('fullStaticUrl') + '/';
export const JupyterLabApp = (props) => {
    const { hostId, position, height, width, headless, theme, onJupyterLab, pluginId, PluginType, onPlugin, } = props;
    const { serviceManager, collaborative } = useJupyter();
    const ref = useRef(null);
    const [_, setAdapter] = useState();
    useEffect(() => {
        if (ref && serviceManager) {
            if (!_adapter) {
                _adapter = new JupyterLabAppAdapter({
                    ...props,
                    collaborative,
                    serviceManager,
                });
            }
            _adapter.ready.then(() => {
                onJupyterLab(_adapter);
                if (pluginId && PluginType && onPlugin) {
                    const plugin = _adapter.service(pluginId);
                    onPlugin(plugin);
                }
            });
            setAdapter(_adapter);
        }
    }, [hostId, ref, serviceManager, theme]);
    return (_jsx(_Fragment, { children: _jsxs(Box, { sx: {
                '& .jp-LabShell': {
                    position: position,
                    height: height,
                    width: width,
                    display: headless ? 'none' : 'inherit',
                },
            }, children: [_jsx(JupyterLabAppCss, { theme: theme }), _jsx("div", { ref: ref, id: hostId })] }) }));
};
JupyterLabApp.defaultProps = {
    devMode: false,
    extensions: [],
    headless: false,
    height: "100vh",
    hostId: "app-example-id",
    mimeExtensions: [],
    onJupyterLab: (jupyterLabAppAdapter) => { },
    position: "relative",
    splash: true,
    theme: 'light',
    width: "100%",
};
export default memo(JupyterLabApp);
//# sourceMappingURL=JupyterLabApp.js.map