// import { Widget } from '@lumino/widgets';
import { JupyterLab } from '@jupyterlab/application';
import { LabShell } from '@jupyterlab/application';
import { JupyterLabAppCorePlugins } from "./JupyterLabAppPlugins";
export class JupyterLabAppAdapter {
    _jupyterLab;
    _shell;
    _plugins;
    _ready;
    _readyResolve;
    constructor(props, jupyterlab) {
        if (jupyterlab) {
            this._jupyterLab = jupyterlab;
            this._ready = new Promise((resolve, _) => {
                this._readyResolve = resolve;
            });
            this._plugins = this._jupyterLab['_plugins'];
            this._readyResolve();
            return;
        }
        this._ready = new Promise((resolve, _) => {
            this._readyResolve = resolve;
        });
        this.load(props);
    }
    async load(props) {
        const { hostId, extensions, mimeExtensions, collaborative, splash, extensionPromises, mimeExtensionPromises, devMode, serviceManager, } = props;
        const mimeExtensionResolved = await Promise.all(mimeExtensionPromises ?? JupyterLabAppCorePlugins(collaborative).mimeExtensionPromises);
        mimeExtensions.push(...mimeExtensionResolved);
        this._shell = new LabShell();
        this._jupyterLab = new JupyterLab({
            shell: this._shell,
            mimeExtensions,
            devMode,
            serviceManager,
            disabled: {
                patterns: [],
                matches: [],
            },
            deferred: {
                patterns: [],
                matches: [],
            },
        });
        const extensionResolved = await Promise.all(extensionPromises ?? JupyterLabAppCorePlugins(collaborative).extensionPromises);
        extensions.push(...extensionResolved);
        this._jupyterLab.registerPluginModules(extensions);
        if (!splash) {
            this._jupyterLab.deregisterPlugin('@jupyterlab/apputils-extension:splash', true);
        }
        /*
        if (collaborative) {
          this._jupyterLab.deregisterPlugin("@jupyterlab/filebrowser-extension:default-file-browser", true);
        }
        */
        this._jupyterLab.start({
            hostID: hostId,
            startPlugins: [],
            ignorePlugins: [],
        });
        this._jupyterLab.restored.then(() => {
            this._plugins = this._jupyterLab['_plugins'];
            this._readyResolve();
        });
    }
    static create(jupyterLab) {
        return new JupyterLabAppAdapter(undefined, jupyterLab);
    }
    get jupyterLab() {
        return this._jupyterLab;
    }
    get shell() {
        return this._jupyterLab.shell;
    }
    get docRegistry() {
        return this._jupyterLab.docRegistry;
    }
    get commands() {
        return this._jupyterLab.commands;
    }
    get serviceManager() {
        return this._jupyterLab.serviceManager;
    }
    get mimeExtensions() {
        return this._jupyterLab.info.mimeExtensions;
    }
    get info() {
        return this._jupyterLab.info;
    }
    get path() {
        return this._jupyterLab.paths;
    }
    get plugins() {
        return this._plugins;
    }
    get ready() {
        return this._ready;
    }
    plugin(id) {
        return this._plugins.get(id);
    }
    service(id) {
        return this._plugins.get(id)?.service;
    }
}
export default JupyterLabAppAdapter;
//# sourceMappingURL=JupyterLabAppAdapter.js.map